Author: oracle
Date: Mon Jul  7 14:37:17 2008
New Revision: 27811

URL: http://svn.gna.org/viewcvs/wesnoth?rev=27811&view=rev
Log:
Continuing with wail customization. Imported
with_statement to clean locking semantics.


Modified:
    trunk/data/ais/bruteforce_wail.py

Modified: trunk/data/ais/bruteforce_wail.py
URL: 
http://svn.gna.org/viewcvs/wesnoth/trunk/data/ais/bruteforce_wail.py?rev=27811&r1=27810&r2=27811&view=diff
==============================================================================
--- trunk/data/ais/bruteforce_wail.py (original)
+++ trunk/data/ais/bruteforce_wail.py Mon Jul  7 14:37:17 2008
@@ -2,8 +2,10 @@
 
 # Sample implementation - converting to the wail library rather than
 # wesnoth directly. This show how easily bot writers can convert old
-# bots, which maintained namespace, to wail.
-# Wail requires Python 2.5+.
+# bots, which maintained namespace, to the wail.
+# Wail requires Python 2.5+. If the following statement fails, you likely
+# are not running Python 2.5.x or later.
+from __future__ import with_statement
 
 import time
 import wail, random


_______________________________________________
Wesnoth-commits mailing list
[email protected]
https://mail.gna.org/listinfo/wesnoth-commits

Reply via email to